@@ -14,7 +14,7 @@ from holoviews import streams
 import cv2
 #from holoviews import opts
 #from holoviews.streams import Stream, param
-hv.notebook_extension('bokeh')
+# hv.notebook_extension('bokeh')
 
 
 
